"""Utilities for dascore."""
from .time import to_datetime64, to_timedelta64
